#
# spec file for package virt-utils
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qemu_utils 1
%define internal_utils 1
%define provide_duplicated_binaries 0

Name:           virt-utils
BuildRequires:  glib2-devel
BuildRequires:  python
BuildRequires:  zlib-devel
BuildRequires:	ceph-devel
Version:        1.1.7
Release:        10.1
Summary:        Virtualization Utilities
License:        GPL-2.0
Group:          System/Kernel
# git commit id for following rc0 release: b8095f2
Source0:        qemu-0.15.0.tar.bz2
Source1:        vm-snapshot-disk
Patch1:         qemu-img-vmdk-scsi.patch
Patch2:         qemu-img-git-vpc-fix.patch
Patch3:         qemu-img-vpc-fixed-disk.patch
Patch4:         qemu-img-vpc-roundup-fix.patch
Url:            http://www.qemu.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Various virtualization solutions have a common need for ancillary
utilities which manage storage, snapshotting, monitoring, etc.

Both KVM and Xen derive their device and machine model from qemu and
inherit a lot from it's approach to emulation/virtualization.  This
package is hence a good place to have qemu related tools reside. 
Additionally, any other utilities which have use across the various
virtualization solutions available have a home here.



Authors:
--------
    Fabrice Bellard
    Ron Terry

%prep
%if %{?qemu_utils}0
%setup -q -n qemu-0.15.0
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%endif

%build
%if %{?qemu_utils}0
./configure --prefix=%{_prefix} --enable-rbd \
	--extra-cflags="%{optflags}"
make qemu-img
make qemu-nbd
make qemu-img.1
make qemu-nbd.8
%endif

%install
%if %{?qemu_utils}0
mkdir -p %{buildroot}%{_bindir}
install -s -m 755 qemu-img %{buildroot}%_bindir/qemu-img
install -s -m 755 qemu-nbd %{buildroot}%_bindir/qemu-nbd
%if %{provide_duplicated_binaries}0 
ln -s qemu-img %{buildroot}%_bindir/qemu-img-xen
ln -s qemu-img %{buildroot}%_bindir/qemu-img-kvm
ln -s qemu-nbd %{buildroot}%_bindir/qemu-nbd-xen
%endif
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_mandir}/man8
install -m644 qemu-img.1 %{buildroot}%_mandir/man1/qemu-img.1
install -m644 qemu-nbd.8 %{buildroot}%_mandir/man8/qemu-nbd.8
%endif
%if %{?internal_utils}0
install -m 755 %SOURCE1 $RPM_BUILD_ROOT/usr/bin
%endif

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-, root, root)
%if %{?qemu_utils}0
/usr/bin/qemu-img
/usr/bin/qemu-nbd
%if %{provide_duplicated_binaries}0 
/usr/bin/qemu-img-xen
/usr/bin/qemu-img-kvm
/usr/bin/qemu-nbd-xen
%endif
%{_mandir}/man1/qemu-img.1.gz
%{_mandir}/man8/qemu-nbd.8.gz
%endif
%if %{?internal_utils}0
/usr/bin/vm-snapshot-disk
%endif

%changelog
* Wed Feb 15 2012 hmacht@suse.de
- Build with support for rbd
* Tue Feb  7 2012 carnold@novell.com
- vpc: Round up image size during fixed image creation
  qemu-img-vpc-roundup-fix.patch
* Wed Feb  1 2012 cthiel@suse.com
- add python to BuildRequires (fixes build on openSUSE 11.4 and SLE 11)
* Tue Jan 31 2012 carnold@novell.com
- fate#309765: Create images that can be run on Microsoft Hyper-V host
  qemu-img-vpc-fixed-disk.patch
* Fri Oct 28 2011 carnold@novell.com
- fate#309765: Create images that can be run on Microsoft Hyper-V host
  Fixes vpc file format data offset field in the Dynamic Disk Header
  qemu-img-git-vpc-fix.patch
* Mon Aug  8 2011 brogers@novell.com
- update to qemu version 0.15.0
* Fri Jul 29 2011 brogers@novell.com
- update to qemu version 0.15.0-rc0
* Thu Jul 14 2011 brogers@novell.com
- update to latest qemu snapshot (git id: cf973e4)
- update vm-snapshot-disk script to support vhd disks and create
  reflink snapshots of any disk image type on an ocfs2 volume.
* Mon Feb 21 2011 brogers@novell.com
- Update to qemu-0.14.0
  See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14
- vmdk scsi support now done through -o scsi=on
* Thu Nov  4 2010 brogers@novell.com
- Update to qemu-0.13.0
* Tue Aug 24 2010 brogers@novell.com
- Fix vmdk -s option. Studio needs the -s option for qemu-img to allow
  for the creation of SCSI vmdk images. It got broken when forward porting
  the patch, and went unnoticed until now. (bnc#623623, bnc#633905)
* Mon Mar  8 2010 brogers@novell.com
- Update to qemu-0.12.3
- Brought in full upstream qemu-overflow.patch
* Sun Mar  7 2010 aj@suse.de
- Fix FORTIFY_SOURCE bug found by gcc4.5 with upstream patch qemu-overflow.patch.
* Fri Feb 19 2010 brogers@novell.com
- Update to qemu-0.12.2
- Update vm-snapshot-disk script
- Fix possible segfault during rebase
- Fix can't create qcow image based on read-only image
* Mon Jan 18 2010 brogers@novell.com
- Include image rebase capability - much anticipated snapshot
  supporting functionality.
* Mon Jan 11 2010 jfehlig@novell.com
- Build virt-utils for all architectures
* Thu Dec 31 2009 brogers@novell.com
- Update qemu tools to 0.12.1
- Include qemu package patch to allow creation of SCSI VMDK images
* Thu Nov 19 2009 brogers@novell.com
- Initial checkin of package split from xen package. See FATE#305328
